CHANGES
=======

* Start working with workflows
* Updated docs

v0.0.7
------

* release 0.0.7
* Add desktop file for \*NIX platforms
* Fixing dependencies versions
* Project adapted for the use of pbr
* Fixing doc generation
* Add documentation build requirements
* Started working on documentation

v0.0.5
------

* Make app compatible with python >=3.8

v0.0.4
------

* Remove unused packages and disused methods
* Fix bug when undo then merging
* Add cancel button to progress bar, sort images by name
* Add progress bar to generation

v0.0.3
------

* Fix bugs
* Updated PyPi package
* Reorganizes code for Python packaging
* Add undo button and fixes few bugs
* Fixed bugs with merging preview and following PEP8 file naming convention
* Qfix: layer label
* Implemented reset in editor
* Modifications made in the cluster editor are now temporary and the apply to all button allows to apply the merger to every selected cluster
* Remove debug output
* QFix
* Make merge on all working
* Removed old files
* Reorganized code
* Working on merging layers
* Layout improvements
* Working GUI
* Create output directory when not exists
* Started implementing API
* Add LICENSE
* Initial commit
